@@ -61,6 +61,20 @@
  * -add commands option to sybnext, hacked from Oratcl 2.1
  * -change Sybtcl_Init to (int)
  *-----------------------------------------------------------------------------
+ * Version 2.11, April, 1994
+ * Tom Poindexter
+ * tpoind@advtech.uswest.com  or  tpoindex@nyx.cs.du.edu
+ * -allow sybcols to return column names even if result set is empty
+ *  (thanks Christopher Hall)
+ *-----------------------------------------------------------------------------
+ * Version 2.2, October, 1994
+ * Tom Poindexter
+ * tpoindex@nyx.cs.du.edu
+ * -clean up rest of external function names (Tcl*** -> Sybtcl***)
+ * -add sybase date formatting option  (thanks Ken Corey)
+ * -allow numeric columns to have an actual null output (""), 
+ *  (thanks Ken Corey) 
+ *-----------------------------------------------------------------------------
  *
  */
 
@@ -87,7 +101,7 @@ typedef struct SybTclProcs {	/* struct for handle entries */
 #define SYB_BUFF_SIZE	4096	/* conversion buffer size for various needs*/
 
 /* defines for text/image handling - first is our buffer size;other is max */
-#define   TEXT_BUFF_SIZE  32768
+#define   TEXT_BUFF_SIZE   32768
 #define   MAX_SERVER_TEXT  "2147483647"
 
 static SybTclProcs   SybProcs[SYBTCLPROCS];  
@@ -105,16 +119,16 @@ extern char * malloc();
 
 /* prototypes for all functions */
 
-extern Tcl_CmdProc  Tcl_SybConnect;
-extern Tcl_CmdProc  Tcl_SybUse;
-extern Tcl_CmdProc  Tcl_SybSql;
-extern Tcl_CmdProc  Tcl_SybNext;
-extern Tcl_CmdProc  Tcl_SybCols;
-extern Tcl_CmdProc  Tcl_SybCancel;
-extern Tcl_CmdProc  Tcl_SybClose;
-extern Tcl_CmdProc  Tcl_SybRetval;
-extern Tcl_CmdProc  Tcl_SybWrtext;
-extern Tcl_CmdProc  Tcl_SybRdtext;
+extern Tcl_CmdProc  Sybtcl_Connect;
+extern Tcl_CmdProc  Sybtcl_Use;
+extern Tcl_CmdProc  Sybtcl_Sql;
+extern Tcl_CmdProc  Sybtcl_Next;
+extern Tcl_CmdProc  Sybtcl_Cols;
+extern Tcl_CmdProc  Sybtcl_Cancel;
+extern Tcl_CmdProc  Sybtcl_Close;
+extern Tcl_CmdProc  Sybtcl_Retval;
+extern Tcl_CmdProc  Sybtcl_Wrtext;
+extern Tcl_CmdProc  Sybtcl_Rdtext;
 
 
 
@@ -288,16 +302,16 @@ clear_msg(interp)
 {
     /* indices associated with error and message handlers */
     /* ("severity" is shared between err & msg )          */
-    Tcl_SetVar2(interp, SybMsgArray, "msgno",    "", TCL_GLOBAL_ONLY);
-    Tcl_SetVar2(interp, SybMsgArray, "msgtext",  "", TCL_GLOBAL_ONLY);
-    Tcl_SetVar2(interp, SybMsgArray, "severity", "", TCL_GLOBAL_ONLY);
-    Tcl_SetVar2(interp, SybMsgArray, "svrname",  "", TCL_GLOBAL_ONLY);
-    Tcl_SetVar2(interp, SybMsgArray, "procname", "", TCL_GLOBAL_ONLY);
-    Tcl_SetVar2(interp, SybMsgArray, "line",     "", TCL_GLOBAL_ONLY);
-    Tcl_SetVar2(interp, SybMsgArray, "dberr",    "", TCL_GLOBAL_ONLY);
-    Tcl_SetVar2(interp, SybMsgArray, "oserr",    "", TCL_GLOBAL_ONLY);
-    Tcl_SetVar2(interp, SybMsgArray, "dberrstr", "", TCL_GLOBAL_ONLY);
-    Tcl_SetVar2(interp, SybMsgArray, "oserrstr", "", TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "msgno",      "", TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "msgtext",    "", TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "severity",   "", TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "svrname",    "", TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "procname",   "", TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "line",       "", TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "dberr",      "", TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "oserr",      "", TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "dberrstr",   "", TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "oserrstr",   "", TCL_GLOBAL_ONLY);
 
     /* index "nextrow" - the last return from dbnextrow/dbresults     */
     /* text message, or compute column id as integer                  */
@@ -309,8 +323,6 @@ clear_msg(interp)
     /* index "collengths" & "coltypes" only meaningful after sybcols command */
     Tcl_SetVar2(interp, SybMsgArray, "collengths","", TCL_GLOBAL_ONLY);
     Tcl_SetVar2(interp, SybMsgArray, "coltypes",  "", TCL_GLOBAL_ONLY);
-
-
 }
 
 
@@ -383,20 +395,24 @@ parse_column (interp, hand, col_type, col_len, col_ptr)
     int         dst_len;
     int         text_buf_size;
 
+    DBDATEREC   dateinfo;
+    DBDATETIME  convert_date;
+    int         j;
+    char        tempstr[SYB_BUFF_SIZE];
+
 
     /* if column is null, extract the current "nullvalue" */
     if ((col_len == 0) && (col_ptr == (BYTE *)NULL)) {
 
-	strcpy(buf2,
-	 Tcl_GetVar2(interp,SybMsgArray,"nullvalue",TCL_GLOBAL_ONLY));
+	strcpy(buf2, Tcl_GetVar2(interp,SybMsgArray,"nullvalue",
+							   TCL_GLOBAL_ONLY));
+
+	/* if "nullvalue" is  the string "default", append the defaults,    */
+	/* otherwise, append the user requested nullvalue, which could be ""*/
+
+	if (*buf2 == 'd' && strcmp(buf2,"default") == 0) {
+	  /* default-if number or money type, then return "0", else ""       */
 
-	/* if "nullvalue" is not null, then append the "nullvalue" & return */
-	if (strlen(buf2) > 0) {
-            Tcl_AppendElement(interp, buf2);
-	} else {
- 	  /* else,"nullvalue" is null. dbconvert converts to null dest type.*/
-	  /* instead, we want a string representation of the source type as */
-	  /* null.  if number or money type, then return "0", else ""       */
           if (col_type == SYBINT1 ||
               col_type == SYBINT2 ||
               col_type == SYBINT4 ||
@@ -408,12 +424,18 @@ parse_column (interp, hand, col_type, col_len, col_ptr)
 	  } else {
             Tcl_AppendElement(interp, "");
 	  }
+
+	} else {
+          Tcl_AppendElement(interp, buf2);
 	}
 
 	return (1);
 	  
     } 
 
+    /* copy whatever value's in sybmsg(dateformat) to buf2 */
+    strcpy(buf2, Tcl_GetVar2(interp,SybMsgArray,"dateformat",TCL_GLOBAL_ONLY));
+
     /* only convert text & image to the extent of buffer size */
     if ((col_type == SYBTEXT) || (col_type == SYBIMAGE)) {
         text_buf_size = atoi(
@@ -426,14 +448,85 @@ parse_column (interp, hand, col_type, col_len, col_ptr)
 	    return (0);
         }
         memset(buf,'\0',text_buf_size+2); 
-	if (col_len >= (text_buf_size)) {
+      if (col_len >= (text_buf_size)) {
 	    dst_len = text_buf_size;  /* leave room for null */
-	} else {
+      } else {
 	    dst_len = -1;	/* dbconvert will null terminate */
-	}
+      }
+
+    /* if buf2 has a value in it, then there's a particular format */
+    /* the user wants us to use for the date.  If not, we'll default */
+    /* to the standard date output string. */
+    } else if (((col_type == SYBDATETIME) || (col_type == SYBDATETIME4))
+               && strlen(buf2) > 0) {
+      buf = ckalloc(SYB_BUFF_SIZE);
+      if (buf == NULL) {
+        Tcl_SetResult (interp, 
+          "parse_column cannot malloc memory for date format", TCL_VOLATILE);
+        return (0);
+      }
+      if (col_type == SYBDATETIME4) {
+          dbconvert(SybProcs[hand].dbproc,col_type, col_ptr, col_len, 
+			    SYBDATETIME, &convert_date, sizeof(convert_date));
+	  col_ptr = (BYTE *) &convert_date;
+      }
+      buf[0] = '\0';
+      dbdatecrack(SybProcs[hand].dbproc,&dateinfo,col_ptr);
+      j=0;
+      while(j < strlen(buf2)) {
+        if (!strncmp(&(buf2[j]),"YYYY",4)) {
+          sprintf(tempstr,"%04d",dateinfo.dateyear);
+          j += 4;
+        } else if (!strncmp(&(buf2[j]),"YY",2)) {
+          sprintf(tempstr,"%02d",dateinfo.dateyear % 100);
+          j += 2;
+        } else if (!strncmp(&(buf2[j]),"MONTH",5)) {
+          strcpy(tempstr,dbmonthname(SybProcs[hand].dbproc,(char *)NULL,
+                                     dateinfo.datemonth+1,FALSE));
+          j += 5;
+        } else if (!strncmp(&(buf2[j]),"MON",3)) {
+          strcpy(tempstr,dbmonthname(SybProcs[hand].dbproc,(char *)NULL,
+                                     dateinfo.datemonth+1,TRUE));
+          j += 3;
+        } else if (!strncmp(&(buf2[j]),"MM",2)) {
+          sprintf(tempstr,"%02d",dateinfo.datemonth + 1);
+          j += 2;
+        } else if (!strncmp(&(buf2[j]),"DD",2)) {
+          sprintf(tempstr,"%02d",dateinfo.datedmonth);
+          j += 2;
+        } else if (!strncmp(&(buf2[j]),"hh",2)) {
+          sprintf(tempstr,"%02d",dateinfo.datehour);
+          j += 2;
+        } else if (!strncmp(&(buf2[j]),"mm",2)) {
+          sprintf(tempstr,"%02d",dateinfo.dateminute);
+          j += 2;
+        } else if (!strncmp(&(buf2[j]),"ss",2)) {
+          sprintf(tempstr,"%02d",dateinfo.datesecond);
+          j += 2;
+        } else if (!strncmp(&(buf2[j]),"dy",2)) {
+          sprintf(tempstr,"%03d",dateinfo.datedyear);
+          j += 2;
+        } else if (!strncmp(&(buf2[j]),"dw",2)) {
+          sprintf(tempstr,"%02d",dateinfo.datedweek + 1);
+          j += 2;
+        } else if (!strncmp(&(buf2[j]),"ms",2)) {
+          sprintf(tempstr,"%03d",dateinfo.datemsecond);
+          j += 2;
+        } else {
+          tempstr[0] = buf2[j];
+          tempstr[1] = '\0';
+          j++;
+        }
+        strcat(buf,tempstr);
+      }
+      Tcl_AppendElement(interp,buf);
+      ckfree(buf);
+      return (1);
+
+
     } else {
-	buf = buf2;     /* use buf2 storage */
-	dst_len = -1;	/* dbconvert will null terminate */
+      buf = buf2;       /* use buf2 storage */
+      dst_len = -1;	/* dbconvert will null terminate */
     }
 
     dbconvert(SybProcs[hand].dbproc,col_type, col_ptr, col_len, 
@@ -451,13 +544,13 @@ parse_column (interp, hand, col_type, col_len, col_ptr)
 
 /*
  *----------------------------------------------------------------------
- * Tcl_KillSyb --
+ * Sybtcl_Kill --
  *   perform all cleanup upon any command deletion
  *
  */
 
 void
-Tcl_KillSyb (clientData)
+Sybtcl_Kill (clientData)
     ClientData clientData;
 {
     int i;
@@ -513,26 +606,26 @@ Sybtcl_Init (interp)
      * Initialize the new Tcl commands
      */
 
-    Tcl_CreateCommand (interp, "sybconnect", Tcl_SybConnect, (ClientData)NULL,
-		      Tcl_KillSyb);
-    Tcl_CreateCommand (interp, "sybuse",     Tcl_SybUse,     (ClientData)NULL,
-		      Tcl_KillSyb);
-    Tcl_CreateCommand (interp, "sybsql",     Tcl_SybSql,     (ClientData)NULL,
-		      Tcl_KillSyb);
-    Tcl_CreateCommand (interp, "sybnext",    Tcl_SybNext,    (ClientData)NULL,
-		      Tcl_KillSyb);
-    Tcl_CreateCommand (interp, "sybcols",    Tcl_SybCols,    (ClientData)NULL,
-		      Tcl_KillSyb);
-    Tcl_CreateCommand (interp, "sybcancel",  Tcl_SybCancel,  (ClientData)NULL,
-		      Tcl_KillSyb);
-    Tcl_CreateCommand (interp, "sybretval",  Tcl_SybRetval,  (ClientData)NULL,
-		      Tcl_KillSyb);
-    Tcl_CreateCommand (interp, "sybclose",   Tcl_SybClose,   (ClientData)NULL,
-		      Tcl_KillSyb);
-    Tcl_CreateCommand (interp, "sybwritetext",Tcl_SybWrtext, (ClientData)NULL,
-		      Tcl_KillSyb);
-    Tcl_CreateCommand (interp, "sybreadtext",Tcl_SybRdtext,  (ClientData)NULL,
-		      Tcl_KillSyb);
+    Tcl_CreateCommand (interp, "sybconnect", Sybtcl_Connect, (ClientData)NULL,
+		      Sybtcl_Kill);
+    Tcl_CreateCommand (interp, "sybuse",     Sybtcl_Use,     (ClientData)NULL,
+		      Sybtcl_Kill);
+    Tcl_CreateCommand (interp, "sybsql",     Sybtcl_Sql,     (ClientData)NULL,
+		      Sybtcl_Kill);
+    Tcl_CreateCommand (interp, "sybnext",    Sybtcl_Next,    (ClientData)NULL,
+		      Sybtcl_Kill);
+    Tcl_CreateCommand (interp, "sybcols",    Sybtcl_Cols,    (ClientData)NULL,
+		      Sybtcl_Kill);
+    Tcl_CreateCommand (interp, "sybcancel",  Sybtcl_Cancel,  (ClientData)NULL,
+		      Sybtcl_Kill);
+    Tcl_CreateCommand (interp, "sybretval",  Sybtcl_Retval,  (ClientData)NULL,
+		      Sybtcl_Kill);
+    Tcl_CreateCommand (interp, "sybclose",   Sybtcl_Close,   (ClientData)NULL,
+		      Sybtcl_Kill);
+    Tcl_CreateCommand (interp, "sybwritetext",Sybtcl_Wrtext, (ClientData)NULL,
+		      Sybtcl_Kill);
+    Tcl_CreateCommand (interp, "sybreadtext",Sybtcl_Rdtext,  (ClientData)NULL,
+		      Sybtcl_Kill);
 
     /*
      * Initialize sybmsg global array, inital null elements
@@ -543,12 +636,16 @@ Sybtcl_Init (interp)
 
     /* index "nullvalue" - what to return if column is null */
     /* user should set this value if something else is wanted */
-    Tcl_SetVar2(interp, SybMsgArray, "nullvalue", "",TCL_GLOBAL_ONLY);
+    Tcl_SetVar2(interp, SybMsgArray, "nullvalue", "default",TCL_GLOBAL_ONLY);
 
     /* index "maxtext" - the maximum length of a text column to return */
     /* in a select or sybreadtext , can be set by user                 */
     Tcl_SetVar2(interp, SybMsgArray, "maxtext", "32768",TCL_GLOBAL_ONLY);
 
+    /* index "dateformat" - the format that the user wants datetime /*
+    /* values to return in. */
+    Tcl_SetVar2(interp, SybMsgArray, "dateformat", "",TCL_GLOBAL_ONLY);
+
     /* other indices - correspond to error and message handler arguments */
     clear_msg(interp);
 
@@ -561,7 +658,7 @@ Sybtcl_Init (interp)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybConnect --
+ * Sybtcl_Connect --
  *    Implements the sybconnect command:
  *    usage: sybconnect userid password ?server? ?appname?
  *	                
@@ -572,7 +669,7 @@ Sybtcl_Init (interp)
  */
 
 int
-Tcl_SybConnect (clientData, interp, argc, argv)
+Sybtcl_Connect (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
@@ -652,7 +749,7 @@ Tcl_SybConnect (clientData, interp, argc, argv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybUse --
+ * Sybtcl_Use --
  *    Implements the sybuse command:
  *    usage: sybuse handle ?dbname?
  *	                
@@ -662,7 +759,7 @@ Tcl_SybConnect (clientData, interp, argc, argv)
  *      TCL_ERROR - wrong # args, or handle not opened
  */
 
-Tcl_SybUse (clientData, interp, argc, argv)
+Sybtcl_Use (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
@@ -695,7 +792,7 @@ Tcl_SybUse (clientData, interp, argc, argv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybSql --
+ * Sybtcl_Sql --
  *    Implements the sybsql command:
  *    usage: sybsql handle sql-string 
  *	                
@@ -705,7 +802,7 @@ Tcl_SybUse (clientData, interp, argc, argv)
  *      TCL_ERROR - wrong # args, or handle not opened,  bad sql stmt
  */
 
-Tcl_SybSql (clientData, interp, argc, argv)
+Sybtcl_Sql (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
@@ -804,7 +901,7 @@ Tcl_SybSql (clientData, interp, argc, argv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybNext --
+ * Sybtcl_Next --
  *    Implements the sybnext command:
  *    usage: sybnext handle ?commands?
  *	                
@@ -815,7 +912,7 @@ Tcl_SybSql (clientData, interp, argc, argv)
  *      TCL_ERROR - wrong # args, or handle not opened
  */
 
-Tcl_SybNext (clientData, interp, argc, argv)
+Sybtcl_Next (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
@@ -830,7 +927,7 @@ Tcl_SybNext (clientData, interp, argc, argv)
     int     col_len;
     BYTE   *col_ptr;
     int     dst_len;
-    int     Tcl_SybNextAll();
+    int     Sybtcl_NextAll();
 
 
     if ((hand = syb_prologue(interp, argc, argv, 2, " handle")) == -1) {
@@ -839,7 +936,7 @@ Tcl_SybNext (clientData, interp, argc, argv)
 
     /* if commands argument, then call next function to do work */
     if (argc >= 3) {
-	return (Tcl_SybNextAll(clientData, interp, argc, argv));
+	return (Sybtcl_NextAll(clientData, interp, argc, argv));
     }
 
     /* check to see if next set of results */
@@ -969,7 +1066,7 @@ Tcl_SybNext (clientData, interp, argc, argv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybNextAll --
+ * Sybtcl_NextAll --
  *    Implements the sybnext with iterative commands:
  *    hacked from Oratcl 2.1, nearly verbatim
  *    usage: sybnext cur_handle tcl_stmts
@@ -983,7 +1080,7 @@ Tcl_SybNext (clientData, interp, argc, argv)
  */
 
 static int
-Tcl_SybNextAll (clientData, interp, argc, argv)
+Sybtcl_NextAll (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
@@ -1088,7 +1185,7 @@ Tcl_SybNextAll (clientData, interp, argc, argv)
 
     /* loop until fetch exhausted */
 
-    if (Tcl_SybNext(clientData, interp, 2, argv) == TCL_ERROR) {
+    if (Sybtcl_Next(clientData, interp, 2, argv) == TCL_ERROR) {
 	Tcl_AppendResult (interp, ": ", argv[0], ": sybnext failed", 
 			  (char *) NULL);
 	return TCL_ERROR;
@@ -1182,7 +1279,7 @@ Tcl_SybNextAll (clientData, interp, argc, argv)
 	Tcl_ResetResult(interp);	/* reset interp result for next */
  
         /* next fetch */
-        if (Tcl_SybNext(clientData, interp, 2, argv) == TCL_ERROR) {
+        if (Sybtcl_Next(clientData, interp, 2, argv) == TCL_ERROR) {
 	    Tcl_AppendResult (interp, ": ", argv[0], ": sybnext failed", 
 			      (char *) NULL);
 	    return TCL_ERROR;
@@ -1202,7 +1299,7 @@ Tcl_SybNextAll (clientData, interp, argc, argv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybCols --
+ * Sybtcl_Cols --
  *    Implements the sybcols command:
  *    usage: sybcols handle 
  *	                
@@ -1213,7 +1310,7 @@ Tcl_SybNextAll (clientData, interp, argc, argv)
  *      TCL_ERROR - wrong # args, or handle not opened,
  */
 
-Tcl_SybCols (clientData, interp, argc, argv)
+Sybtcl_Cols (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
@@ -1273,7 +1370,8 @@ Tcl_SybCols (clientData, interp, argc, argv)
 
 	} else {
 	    /* check for a regular row */
-	    if (SybProcs[hand].last_next == REG_ROW) {
+	    if ((SybProcs[hand].last_next == REG_ROW) ||
+	        (SybProcs[hand].last_next == NO_MORE_ROWS)) {
 		num_cols = dbnumcols(SybProcs[hand].dbproc);
 
 		for (i = 1; i <= num_cols; i++) {
@@ -1348,7 +1446,7 @@ Tcl_SybCols (clientData, interp, argc, argv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybCancel --
+ * Sybtcl_Cancel --
  *    Implements the sybcancel command:
  *    usage: sybcancel  handle 
  *	                
@@ -1358,7 +1456,7 @@ Tcl_SybCols (clientData, interp, argc, argv)
  *      TCL_ERROR - wrong # args, or handle not opened,
  */
 
-Tcl_SybCancel (clientData, interp, argc, argv)
+Sybtcl_Cancel (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
@@ -1389,7 +1487,7 @@ Tcl_SybCancel (clientData, interp, argc, argv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybRetval --
+ * Sybtcl_Retval --
  *    Implements the sybretval command:
  *    usage: sybretval  handle 
  *	                
@@ -1399,7 +1497,7 @@ Tcl_SybCancel (clientData, interp, argc, argv)
  *      TCL_ERROR - wrong # args, or handle not opened,
  */
 
-Tcl_SybRetval (clientData, interp, argc, argv)
+Sybtcl_Retval (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
@@ -1443,7 +1541,7 @@ Tcl_SybRetval (clientData, interp, argc, argv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybClose --
+ * Sybtcl_Close --
  *    Implements the sybclose command:
  *    usage: sybcose handle 
  *	                
@@ -1453,7 +1551,7 @@ Tcl_SybRetval (clientData, interp, argc, argv)
  *      TCL_ERROR - wrong # args, or handle not opened,
  */
 
-Tcl_SybClose (clientData, interp, argc, argv)
+Sybtcl_Close (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
@@ -1481,7 +1579,7 @@ Tcl_SybClose (clientData, interp, argc, argv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybWrtext --
+ * Sybtcl_Wrtext --
  *    Implements the sybwritetext command:
  *    usage: sybwritetext handle object colnum file ?nolog?
  *      where: object = "table.colum"
@@ -1504,7 +1602,7 @@ Tcl_SybClose (clientData, interp, argc, argv)
  *                  or other bad karma in text/image handling
  */
 
-Tcl_SybWrtext (clientData, interp, argc, argv)
+Sybtcl_Wrtext (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
@@ -1637,7 +1735,7 @@ Tcl_SybWrtext (clientData, interp, argc, argv)
 /*
  *----------------------------------------------------------------------
  *
- * Tcl_SybRdtext --
+ * Sybtcl_Rdtext --
  *    Implements the sybreadtext command:
  *    usage: sybreadtext handle file 
  *
@@ -1653,7 +1751,7 @@ Tcl_SybWrtext (clientData, interp, argc, argv)
  */
 
 
-Tcl_SybRdtext (clientData, interp, argc, argv)
+Sybtcl_Rdtext (clientData, interp, argc, argv)
     ClientData   clientData;
     Tcl_Interp  *interp;
     int          argc;
